@@ -27,8 +27,7 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <gio/gio.h>
 
 #include <string.h>
 #define I_KNOW_RARIAN_0_8_IS_UNSTABLE
@@ -56,9 +55,20 @@ YelpRrnType    yelp_uri_resolve           (gchar        *uri,
 YelpRrnType
 resolve_process_ghelp (char *uri, gchar **result)
 {
+    gboolean uncertain;
     RrnReg *reg = rrn_find_from_ghelp (&uri[6]);
     YelpRrnType type = YELP_RRN_TYPE_ERROR;
 
+    if (!strncmp (uri, "ghelp:", 6)) {
+	reg = rrn_find_from_ghelp (&uri[6]);
+    } else if (!strncmp (uri, "gnome-help:", 11)) {
+	reg = rrn_find_from_ghelp (&uri[11]);
+    } else {
+	g_warning ("Trying to resolve a ghelp URI from a non-ghelp string.");
+	return YELP_RRN_TYPE_ERROR;
+    }
+   
+
     if (reg) {
 	gchar *mime = NULL;
 	if (g_str_has_prefix (reg->uri, "file:"))
@@ -70,8 +80,8 @@ resolve_process_ghelp (char *uri, gchar **result)
 	if (reg->type && *(reg->type))
 	    mime = g_strdup (reg->type);
 	else 
-	    mime = gnome_vfs_get_mime_type (*result);
-	
+	    mime = g_content_type_guess (*result, NULL, 0, &uncertain);
+
 	if (!mime) {
 	    type = YELP_RRN_TYPE_ERROR;
 	} else if (g_str_equal (mime, "text/xml") || 
@@ -149,13 +159,15 @@ resolve_is_man_path (const gchar *path, const gchar *encoding)
 YelpRrnType
 resolve_full_file (const gchar *path)
 {
-    gchar *mime_type;
+    gchar    *mime_type;
+    gboolean  uncertain;
+
     YelpRrnType type = YELP_RRN_TYPE_ERROR;
 
     if (!g_file_test (path, G_FILE_TEST_EXISTS)) {
 	return YELP_RRN_TYPE_ERROR;
     }
-    mime_type = gnome_vfs_get_mime_type (path);
+    mime_type = g_content_type_guess (path, NULL, 0, &uncertain);
     if (mime_type == NULL) {
 	return YELP_RRN_TYPE_ERROR;
     }
@@ -223,7 +235,7 @@ resolve_man_page (const gchar *name, gchar **result, gchar **section)
     if (lbrace) {
 	rbrace = strrchr (name, ')');
 	if (rbrace) {
-	    /*sect = g_strndup (lbrace+1, rbrace - lbrace - 1);*/
+	    sect = g_strndup (lbrace+1, rbrace - lbrace - 1);
 	    real_name = g_strndup (name, lbrace - name);
 	} else {
 	    sect = NULL;
@@ -233,12 +245,12 @@ resolve_man_page (const gchar *name, gchar **result, gchar **section)
 	lbrace = strrchr (name, '.');
 	if (lbrace) {
 	    repeat = TRUE;
-	    /*sect = strdup (lbrace+1);*/
+	    sect = strdup (lbrace+1);
 	    real_name = g_strndup (name, lbrace - name);
 	} else {
 	    lbrace = strrchr (name, '#');
 	    if (lbrace) {
-		/*sect = strdup (lbrace+1);*/
+		sect = strdup (lbrace+1);
 		real_name = g_strndup (name, lbrace - name);
 	    } else {
 		real_name = strdup (name);
